@@ -100,7 +100,7 @@ class PostBoardView(RemoteHtmlMixin, PostBaseView):
     methods
     """
     http_method_names = ['get', 'post', 'put', 'delete', 'head', 'options', 'trace']
-    template_name = "tribune/board.html"
+    template_name = "djangotribune/board.html"
     clock_indexation = True
     
     def get_context_data(self, **kwargs):
@@ -140,14 +140,6 @@ class PostBoardView(RemoteHtmlMixin, PostBaseView):
             self.command.patch_response(response)
         
         return response
-
-    #def patch_row(self, row):
-        #"""
-        #Add a *clockclass* suitable in ``class=""``, it's a combination of ``clock`` and 
-        #``clock_indice`` (padded on two digits)
-        #"""
-        #row['clockclass'] = row['clock'].strftime("%H%M%S") + str(row.get('clock_indice', 1))
-        #return row
         
     def get_success_url(self):
         """
@@ -160,7 +152,7 @@ class PostBoardNoScriptView(PostBoardView):
     """
     HTML Interface view duplicata with different template
     """
-    template_name = "tribune/board_noscript.html"
+    template_name = "djangotribune/board_noscript.html"
 
 class PostRemotePlainView(RemotePlainMixin, PostRemoteBaseView):
     """
